@@ -34,6 +34,7 @@ class IpmiTimeoutError(Exception):
 
 class CompletionCodeError(Exception):
     """IPMI completion code not OK."""
+
     def __init__(self, cc, cmd_id=None):
         self.cc = cc
         self.cc_desc = self.find_cc_desc(cc)
@@ -71,5 +72,5 @@ class DataNotFound(Exception):
 
 
 class HpmError(Exception):
-    """HPM.1 error"""
+    """HPM.1 error."""
     pass
