@@ -20,9 +20,11 @@ from ..logger import log
 from ..msgs import (create_message, create_request_by_name,
                     encode_message, decode_message, constants)
 from ..utils import check_completion_code
+from ..utils import py3_array_tobytes, py3_array_frombytes
 
 
 def checksum(data):
+    """Calculate the checksum."""
     csum = 0
     for b in data:
         csum += b
@@ -41,8 +43,8 @@ class IpmbHeader(object):
     *-------*--------------*----------*-------*---------------*--------*
     | rq_sa | netfn/rq_lun | checksum | rs_sa | rq_seq/rs_lun | cmd_id |
     *-------*--------------*----------*-------*---------------*--------*
-
     """
+
     rs_sa = None
     rs_lun = None
     rq_sa = None
@@ -54,7 +56,10 @@ class IpmbHeader(object):
 
 
 class IpmbHeaderReq(IpmbHeader):
+    """Representation of the IPMI request message header."""
+
     def encode(self):
+        """Encode the header."""
         data = array('B')
         data.append(self.rs_sa)
         data.append(self.netfn << 2 | self.rs_lun)
@@ -62,17 +67,22 @@ class IpmbHeaderReq(IpmbHeader):
         data.append(self.rq_sa)
         data.append(self.rq_seq << 2 | self.rq_lun)
         data.append(self.cmd_id)
-        return data.tostring()
+        return py3_array_tobytes(data)
 
     def decode(self):
+        """Decode the header."""
         raise NotImplementedError()
 
 
 class IpmbHeaderRsp(IpmbHeader):
+    """Representation of the IPMI response message header."""
+
     def encode(self):
+        """Encode the header."""
         raise NotImplementedError()
 
     def decode(self, data):
+        """Decode the header."""
         data = array('B', data)
         self.rq_sa = data[0]
         self.netfn = data[1] >> 2
@@ -93,14 +103,13 @@ def encode_ipmb_msg(header, data):
     Returns the message as bytestring.
     """
     msg = array('B')
-
-    msg.fromstring(header.encode())
+    py3_array_frombytes(msg, header.encode())
     if data is not None:
         a = array('B')
-        a.fromstring(data)
+        py3_array_frombytes(a, data)
         msg.extend(a)
     msg.append(checksum(msg[3:]))
-    return msg.tostring()
+    return py3_array_tobytes(msg)
 
 
 def encode_send_message(payload, rq_sa, rs_sa, channel, seq, tracking=1):
@@ -142,7 +151,6 @@ def encode_bridged_message(routing, header, payload, seq):
 
     Returns the encoded send message as bytestring
     """
-
     # change header requester addresses for bridging
     header.rq_sa = routing[-1].rq_sa
     header.rs_sa = routing[-1].rs_sa
@@ -165,7 +173,6 @@ def decode_bridged_message(rx_data):
 
     Returns the decoded message as bytestring
     """
-
     while array('B', rx_data)[5] == constants.CMDID_SEND_MESSAGE:
         rsp = create_message(constants.NETFN_APP + 1,
                              constants.CMDID_SEND_MESSAGE, None)
@@ -191,7 +198,6 @@ def rx_filter(header, data):
     header: the header to compare with
     data: the received message as bytestring
     """
-
     rsp_header = IpmbHeaderRsp()
     rsp_header.decode(data)
 
