@@ -32,7 +32,7 @@ from ..logger import log
 from ..interfaces.ipmb import (IpmbHeaderReq, encode_ipmb_msg,
                                encode_bridged_message, decode_bridged_message,
                                rx_filter)
-from ..utils import check_completion_code
+from ..utils import check_completion_code, py3_array_tobytes
 
 
 CLASS_NORMAL_MSG = 0x00
@@ -215,8 +215,11 @@ class IpmiMsg(object):
         return struct.unpack("<I", struct.pack(">I", seq))[0]
 
     def _padd_password(self):
-        """The password/key is 0 padded to 16-bytes for all specified
-        authentication types."""
+        """Padd the password.
+
+        The password/key is 0 padded to 16-bytes for all specified
+        authentication types.
+        """
         password = self.session._auth_password
         if isinstance(password, str):
             password = str.encode(password)
@@ -262,7 +265,7 @@ class IpmiMsg(object):
         else:
             raise NotSupportedError('authentication type %s' % auth_type)
 
-        pdu += array('B', [data_len]).tostring()
+        pdu += py3_array_tobytes(array('B', [data_len]))
 
         if sdu is not None:
             pdu += sdu
@@ -328,6 +331,7 @@ class Rmcp(object):
         self.keep_alive_interval = keep_alive_interval
         self._stop_keep_alive = None
         self._q = Queue()
+        self.transaction_lock = threading.Lock()
 
     def _send_rmcp_msg(self, sdu, class_of_msg):
         rmcp = RmcpMsg(class_of_msg)
@@ -519,22 +523,23 @@ class Rmcp(object):
         else:
             tx_data = encode_ipmb_msg(header, payload)
 
-        self._send_ipmi_msg(tx_data)
+        with self.transaction_lock:
+            self._send_ipmi_msg(tx_data)
 
-        received = False
-        while received is False:
-            if not self._q.empty():
-                rx_data = self._q.get()
-            else:
-                rx_data = self._receive_ipmi_msg()
+            received = False
+            while received is False:
+                if not self._q.empty():
+                    rx_data = self._q.get()
+                else:
+                    rx_data = self._receive_ipmi_msg()
 
-            if array('B', rx_data)[5] == constants.CMDID_SEND_MESSAGE:
-                rx_data = decode_bridged_message(rx_data)
+                if array('B', rx_data)[5] == constants.CMDID_SEND_MESSAGE:
+                    rx_data = decode_bridged_message(rx_data)
 
-            received = rx_filter(header, rx_data)
+                received = rx_filter(header, rx_data)
 
-            if not received:
-                self._q.put(rx_data)
+                if not received:
+                    self._q.put(rx_data)
 
         return rx_data[6:-1]
 
